/*
 * Copyright (C) 2022 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package android.location;


/**
 * This class represents a GNSS signal type.
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public final class GnssSignalType implements android.os.Parcelable {

GnssSignalType() { throw new RuntimeException("Stub!"); }

/**
 * Creates a {@link android.location.GnssSignalType GnssSignalType} with a full list of parameters.
 *
 * @param constellationType the constellation type
 * Value is {@link android.location.GnssStatus#CONSTELLATION_UNKNOWN}, {@link android.location.GnssStatus#CONSTELLATION_GPS}, {@link android.location.GnssStatus#CONSTELLATION_SBAS}, {@link android.location.GnssStatus#CONSTELLATION_GLONASS}, {@link android.location.GnssStatus#CONSTELLATION_QZSS}, {@link android.location.GnssStatus#CONSTELLATION_BEIDOU}, {@link android.location.GnssStatus#CONSTELLATION_GALILEO}, or {@link android.location.GnssStatus#CONSTELLATION_IRNSS}
 * @param carrierFrequencyHz the carrier frequency in Hz
 * Value is 0.0f or greater
 * @param codeType the code type as defined in {@link android.location.GnssMeasurement#getCodeType() GnssMeasurement#getCodeType()}
 
 * This value cannot be {@code null}.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public static android.location.GnssSignalType create(int constellationType, double carrierFrequencyHz, @android.annotation.NonNull java.lang.String codeType) { throw new RuntimeException("Stub!"); }

/**
 * Returns the constellation type.
 * @return Value is {@link android.location.GnssStatus#CONSTELLATION_UNKNOWN}, {@link android.location.GnssStatus#CONSTELLATION_GPS}, {@link android.location.GnssStatus#CONSTELLATION_SBAS}, {@link android.location.GnssStatus#CONSTELLATION_GLONASS}, {@link android.location.GnssStatus#CONSTELLATION_QZSS}, {@link android.location.GnssStatus#CONSTELLATION_BEIDOU}, {@link android.location.GnssStatus#CONSTELLATION_GALILEO}, or {@link android.location.GnssStatus#CONSTELLATION_IRNSS}
 */

public int getConstellationType() { throw new RuntimeException("Stub!"); }

/**
 * Returns the carrier frequency in Hz.
 * @return Value is 0.0f or greater
 */

public double getCarrierFrequencyHz() { throw new RuntimeException("Stub!"); }

/**
 * Return the code type.
 *
 * @see android.location.GnssMeasurement#getCodeType()

 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public java.lang.String getCodeType() { throw new RuntimeException("Stub!"); }

/**
 * {@inheritDoc}

 * @param parcel This value cannot be {@code null}.
 */

public void writeToParcel(@android.annotation.NonNull android.os.Parcel parcel, int flags) { throw new RuntimeException("Stub!"); }

/**
 * {@inheritDoc}

 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public java.lang.String toString() { throw new RuntimeException("Stub!"); }

/**
 * {@inheritDoc}

 * @param obj This value may be {@code null}.
 */

public boolean equals(@android.annotation.Nullable java.lang.Object obj) { throw new RuntimeException("Stub!"); }

public int hashCode() { throw new RuntimeException("Stub!"); }

public int describeContents() { throw new RuntimeException("Stub!"); }

@android.annotation.NonNull public static final android.os.Parcelable.Creator<android.location.GnssSignalType> CREATOR;
static { CREATOR = null; }
}

